@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.117_01';
+our $VERSION = '0.117_02';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1681,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Tue Mar 12 17:02:25 2019 GMT
+# on Thu Mar 14 15:54:34 2019 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1774,7 +1774,7 @@ __PACKAGE__->status( add => 25577, iridium => 'D', 'Iridium 20', 'Decayed 2018-1
 __PACKAGE__->status( add => 25578, iridium => 'D', 'Iridium 11', 'Decayed 2018-10-22' );
 __PACKAGE__->status( add => 25777, iridium => '-', 'Iridium 14', 'Tumbling' );
 __PACKAGE__->status( add => 25778, iridium => 'D', 'Iridium 21', 'Decayed 2018-05-24' );
-__PACKAGE__->status( add => 27372, iridium => '-', 'Iridium 91', 'Tumbling' );
+__PACKAGE__->status( add => 27372, iridium => 'D', 'Iridium 91', 'Decayed 2019-03-13' );
 __PACKAGE__->status( add => 27373, iridium => 'D', 'Iridium 90', 'Decayed 2019-01-23' );
 __PACKAGE__->status( add => 27374, iridium => 'D', 'Iridium 94', 'Decayed 2018-04-18' );
 __PACKAGE__->status( add => 27375, iridium => 'S', 'Iridium 95', '' );
@@ -1785,8 +1785,8 @@ __PACKAGE__->status( add => 27451, iridium => 'D', 'Iridium 98', 'Decayed 2018-0
 # Summary:
 # Operational [+]: 2
 #       Spare [S]: 6
-#    Tumbling [-]: 35
-#     Decayed [D]: 54
+#    Tumbling [-]: 34
+#     Decayed [D]: 55
 
 1;
 
